.. module:: cairocffi.xcb

Using XCB surfaces with xcffib
==============================

The :mod:`cairocffi.xcb` module uses xcffib_ as the XCB library to create
graphics for X windows and pixmaps.

.. autoclass:: XCBSurface

.. _xcffib: https://github.com/tych0/xcffib/
